''' Este é o módulo "nester.py", e fornece uma função chamada print_lol()
que imprime listas que podem ou não incluir listas aninhadas.'''

def print_lol(the_list):
    '''Esta função requer um argumento posicional chamado "the_list", que é qualquer
    lista Python (de possíveis listas aninhadas). Cada item de dados na lista
    fornecida é (recursivamente) impresso na tela em sua prórpia linha.'''
    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item)
        else:
            print(each_item)


from distutils.core import setup

setup(
        name='nester_brnox',
        version='1.0.0',
        py_modules=['nester_brnox'],
        author='hfpython',
        author_email='hfpython@headfirstlabs.com',
        url='http://www.headfirstlabs.com',
        description='A simple printer of nested lists',
    )